# Change Log

## [0.3.0](https://github.com/dldevinc/django-spectrum/tree/v0.3.0) - 2022-01-17
- Drop support for Python 3.5
- Add support for Python 3.1, Django 3.2 and Django 4.0
- Added `Error` suffix to all exceptions.

## [0.2.1](https://github.com/dldevinc/django-spectrum/tree/v0.2.1) - 2021-02-17
- Fix missing templates

## [0.2.0](https://github.com/dldevinc/django-spectrum/tree/v0.2.0) - 2021-02-13
- `Color` class has been changed in a **backward incompatible** way
- Drop Python 3.4 support
- Migrate to [pickr](https://github.com/Simonwep/pickr)
